@@ -4,8 +4,8 @@ martian_api.
 The martian python library allows developers to easily access the martian api.
 """
 
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 __author__ = 'Shriyash Upadhyay'
 __credits__ = 'Martian'
 
-from .martian import *
\ No newline at end of file
+from .martian_api import *
\ No newline at end of file
