@@ -2,7 +2,7 @@ import json
 import requests
 import time
 
-def log_to_martian(config, input_, output, metadata):
+def log_to_martian(config, input_, output, metadata={}):
     headers = {
         'Content-Type': 'application/json',
         'Authorization': f'Bearer {config["api_key"]}'
